# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   interfaceAutoTest_v4
# FileName:      db.py
# Author:       ALuo
# Datetime:     2023/11/5 22:53
# Description: 配置数据库连接
# ---------------------------------------------------------------------------
import pymysql

from interfaceAutoTest.common import alog
from interfaceAutoTest.common.read_ini import ReadIni
from interfaceAutoTest.data_config.setting import *


class DB:

    def __init__(self):
        read_ini = ReadIni()
        try:
            self.conn = pymysql.connect(
                host=read_ini.get_sql_msg(SQL_Host),
                port=int(read_ini.get_sql_msg(Port)),
                user=read_ini.get_sql_msg(User),
                password=read_ini.get_sql_msg(Password),
                database=read_ini.get_sql_msg(DataBase),
                charset="utf8"
            )
            self.cursor = self.conn.cursor()
        except:
            alog.error("数据库连接错误")
            raise pymysql.MySQLError("数据库连接错误")

    def close(self):
        self.cursor.close()
        self.conn.close()

    def select(self, sql, num=None):
        """
            当传入num时，获取全部查询结果
            默认num为None，此时只会获得结果的第一条第一个信息
        :param sql: sql查询语句
        :param num: 限制条件
        :return: 一个字符串或二维元组
        """
        try:
            self.cursor.execute(sql)
            sql_res = self.cursor.fetchall()
            if num is None:
                return sql_res[0][0]
            else:
                return sql_res
        except:
            alog.error("数据库查询失败，请检查sql语句")
            raise pymysql.MySQLError("数据库语句执行错误")

    def delete(self, sql):
        try:
            self.cursor.execute(sql)
            self.conn.commit()
        except:
            alog.error("数据库语句执行错误")
            raise pymysql.MySQLError("数据库语句执行错误")

if __name__ == '__main__':
    db = DB()
    sql = 'SELECT * FROM uc_demension'

    res_all = db.select(sql, 1)
    print(res_all)

