# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   interfaceAutoTest_v4
# FileName:      read_excel.py
# Author:       ALuo
# Datetime:     2023/11/5 23:51
# Description: 对excel表进行操作
# ---------------------------------------------------------------------------
import os

import openpyxl

from interfaceAutoTest.common import alog
from interfaceAutoTest.common.read_ini import ReadIni
from interfaceAutoTest.common import read_json
from interfaceAutoTest.data_config.setting import *


class ReadExcel:

    def __init__(self, author, table_name):
        """可根据需求填入工作表名，默认为配置文件中表名"""
        # 获取ReadIni对象
        self.read_ini = ReadIni()
        # 获取配置文件的目录
        self.config_dir = self.read_ini.config_dir
        # 获取配置目录中除了ini文件外的所有路径

    # 多用户操作
        # 获取用户数据配置文件目录
        self.author_dir = os.path.join(self.config_dir, author)
        if not os.path.isdir(self.author_dir):
            alog.error("请确保数据配置data_config目录下存在该用户的文件夹：" + author)
            raise KeyError("请确保数据配置data_config目录下存在该用户的文件夹，详情请查看日志")

        # 获取用户配置文件下的文件
        filelist = os.listdir(self.author_dir)
        excel_name = [file for file in filelist if file.endswith(".xlsx")]
        if len(excel_name) != 1:
            alog.error("请确保该用户的文件夹：" + author + " 存在或仅存在一个以'.xlsx'结尾的用例管理表：" + str(excel_name))
            raise FileExistsError("请确保该用户文件下存在或仅存在一个用例管理的excel表")

        self.excel_path = os.path.join(self.author_dir, excel_name[0])
        case_data_path = os.path.join(self.author_dir, Case_Data + ".json")
        expect_data_path = os.path.join(self.author_dir, Expect_Data + ".json")
        sql_data_path = os.path.join(self.author_dir, Sql_Data + ".json")


        # 读取excel表
        self.wb = openpyxl.load_workbook(self.excel_path)
        try:
            self.ws = self.wb[table_name]
        except:
            alog.error("请确保该excel表中" + excel_name[0] + " 存在工作表：" + table_name)
            raise KeyError("请确保表中存在该excel工作表，详情请查看日志")

        # 获取json数据
        self.case_data_dict = read_json.read_json(case_data_path)
        self.expect_data_dict = read_json.read_json(expect_data_path)
        if os.path.isfile(sql_data_path):
            self.sql_data_dict = read_json.read_json(sql_data_path)





    '''
    # 单用户操作
        self.excel_path = self.read_ini.get_file_path(Case_Excel)
        case_data_path = self.read_ini.get_file_path(Case_Data)
        expect_data_path = self.read_ini.get_file_path(Expect_Data)
        sql_data_path = self.read_ini.get_file_path(Sql_Data)
    
    
        # 读取excel表
        if table_name is None:
            table_name = self.read_ini.get_table_name(Table_Name)

        self.wb = openpyxl.load_workbook(self.excel_path)
        try:
            self.ws = self.wb[table_name]
        except:
            alog.error("获取工作表错误，请检查："+table_name)
            raise KeyError("获取工作表错误，请检查，详情请查看日志")
    '''

        # # 获取json数据
        # self.case_data_dict = read_json.read_json(case_data_path)
        # self.expect_data_dict = read_json.read_json(expect_data_path)
        # self.sql_data_dict = read_json.read_json(sql_data_path)

    def __get_cell_value(self, column: str, row: int):
        """根据传入的列号和行号获取某个单元格数据，并做预处理"""
        try:
            cell_value = self.ws[column+str(row)].value
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()
        except:
            alog.error("请检查传入的列号："+column+" 和行号正确："+str(row))
            raise KeyError("请检查传入的列号和行号没有问题，详情请看日志")

    def get_case_module(self, row):
        """根据传入的行号，获取模块名称"""
        return self.__get_cell_value(Case_Module, row)

    def get_case_api(self, row):
        """根据行号，获取api名称"""
        return self.__get_cell_value(Case_API, row)

    def get_case_level(self, row):
        """根据行号，获取用例等级"""
        return self.__get_cell_value(Case_Level, row)

    def get_case_title(self, row):
        """根据行号，获取用例标题"""
        return self.__get_cell_value(Case_Title, row)

    def get_case_method(self, row):
        """根据行号，获取请求方法"""
        return self.__get_cell_value(Case_Method, row)

    def get_url(self, row):
        """根据行号获取请求路径"""
        return self.read_ini.get_host(Test_Host) + self.__get_cell_value(Case_Path, row)

    def get_case_mime(self, row):
        """根据行号，获取媒体类型"""
        mime = self.__get_cell_value(Case_Mime, row)
        if mime:
            return mime.lower()

    def get_case_update_key(self, row):
        """根据行号，获取更新的key"""
        return self.__get_cell_value(Case_Update_Key, row)

    def get_case_sql_type(self, row):
        """根据行号，获取sql类型"""
        return self.__get_cell_value(Case_SQL_Type, row)

    def get_case_data(self, row):
        """获取用例数据"""
        case_data_key = self.__get_cell_value(Case_Data_Key, row)
        module_name = self.get_case_module(row)
        api_name = self.get_case_api(row)
        if case_data_key and module_name and api_name:
            try:
                return self.case_data_dict[module_name][api_name][case_data_key]
            except:
                alog.error("用例数据获取失败")
                raise ValueError("用例数据获取失败")

    def get_expect_data(self, row):
        """获取期望数据"""
        expect_data_key = self.__get_cell_value(Expect_Data_Key, row)
        module_name = self.get_case_module(row)
        api_name = self.get_case_api(row)
        if expect_data_key and module_name and api_name:
            try:
                return self.expect_data_dict[module_name][api_name][expect_data_key]
            except:
                alog.error("期望数据获取失败")
                raise ValueError("期望数据获取失败")

    def get_sql_data(self, row):
        """获取sql数据"""
        sql_data_key = self.__get_cell_value(Case_SQL_Statement, row)
        module_name = self.get_case_module(row)
        api_name = self.get_case_api(row)
        if sql_data_key and module_name and api_name:
            try:
                return self.sql_data_dict[module_name][api_name][sql_data_key]
            except:
                alog.error("sql数据获取失败")
                raise ValueError("sql数据获取失败")

    def get_datas(self):
        """将数据存入一个二维列表中"""
        test_case_datas = []
        max_row = self.ws.max_row
        try:
            for row in range(2, max_row+1):
                # module
                case_module = self.get_case_module(row)
                # api
                case_api = self.get_case_api(row)
                # level
                case_level = self.get_case_level(row)
                # url
                case_url = self.get_url(row)
                # method
                case_method = self.get_case_method(row)
                # mime
                case_mime = self.get_case_mime(row)
                # title
                case_title = self.get_case_title(row)
                # case_data
                case_data = self.get_case_data(row)
                # expect_data
                expect_data = self.get_expect_data(row)
                # sql_type
                sql_type = self.get_case_sql_type(row)
                # sql_data
                sql_data = self.get_sql_data(row)
                # update_key
                update_key = self.get_case_update_key(row)
                # 拼接
                test_case_datas.append(
                    [case_module, case_api, case_title, case_level, case_url, case_method, case_mime, case_data, expect_data, sql_type, sql_data,
                     update_key, row]
                )
            else:
                return test_case_datas
        except:
            alog.error("获取excel表中数据失败，请查看是否存在空行，当前最大行："+str(max_row))
            raise ValueError("获取excel表中数据失败，请查看是否存在空行，详情请查看日志")

    def write_excel(self, result, row):
        if row > 1:
            self.ws[Case_Assert_Result + str(row)] = result
            self.wb.save(self.excel_path)


if __name__ == '__main__':
    read_excel = ReadExcel("alin", "BPM-alin")
    print(read_excel.get_case_data(3))
    print(read_excel.get_expect_data(13))


