# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   interfaceAutoTest_v4
# FileName:      read_ini.py
# Author:       ALuo
# Datetime:     2023/11/5 22:12
# Description:  读取配置文件
# ---------------------------------------------------------------------------
import configparser
import os

from interfaceAutoTest.common import alog
from interfaceAutoTest.data_config.setting import *


class ReadIni:

    def __init__(self):
        # 创建configparser对象读取配置文件
        self.conf = configparser.ConfigParser()
        # 获取该文件目录的父级目录
        par_dir = os.path.dirname(os.path.dirname(__file__))
        # 获取配置文件所在目录
        self.config_dir = os.path.join(par_dir, "data_config")
        if not os.path.isdir(self.config_dir):
            alog.error("请检查配置文件所在目录是否正确："+self.config_dir)
            raise KeyError("请检查配置文件所在目录是否正确，详情请查看日志")
        # print(self.conf_dir) D:\PycharmProjects\interfaceAutoTest_v4\interfaceAutoTest\data_config
        # 获取配置文件所在路径
        conf_path = os.path.join(self.config_dir, "config.ini")
        if not os.path.isfile(conf_path):
            alog.error("请检查配置文件所在路径是否正确："+conf_path)
            raise KeyError("请检查配置文件所在路径是否正确，详情请查看日志")

        # 使用conf读取配置文件
        self.conf.read(conf_path, encoding="utf-8")

    def get_file_path(self, key):
        """根据key读取文件地址"""
        try:
            filename = self.conf.get(FILE, key)
        except:
            alog.error(FILE + " 结点下，key错误：" + key)
            raise KeyError("file结点下的key错误，详情请查看日志")

        file_path = os.path.join(self.config_dir, filename)

        if os.path.isfile(file_path):
            return file_path
        else:
            alog.error("请检查是否存在该文件：" + file_path)
            raise FileExistsError("获取文件错误，详情请查看日志")

    def get_table_name(self, key):
        """根据key获取工作表名"""
        return self.conf.get(TABLE, key)

    def get_host(self, key):
        """根据key获取域名"""
        try:
            return self.conf.get(HOST, key)
        except:
            alog.error(HOST+" 结点下key错误：" + key)
            raise KeyError("host结点下key错误，详情请查看日志")

    def get_sql_msg(self, key):
        """根据key获取sql连接信息"""
        try:
            return self.conf.get(SQL, key)
        except:
            alog.error(SQL+" 结点下key错误：" + key)
            raise KeyError("sql结点下key错误，详情请查看日志")



if __name__ == '__main__':
    read_ini = ReadIni()


